@@ -12,6 +12,7 @@ from trainml.environments import Environment, Environments
 from trainml.jobs import Job, Jobs
 from trainml.connections import Connections
 from trainml.projects import Projects, Project
+from trainml.providers import Providers, Provider
 
 pytestmark = mark.unit
 
@@ -26,7 +27,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="first one",
             status="ready",
-            provider="trainml",
             size=100000000,
             createdAt="2020-12-31T23:59:59.000Z",
         ),
@@ -36,7 +36,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="second one",
             status="ready",
-            provider="trainml",
             size=100000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -46,7 +45,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="first one",
             status="ready",
-            provider="gcp",
             size=100000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -56,7 +54,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="other one",
             status="ready",
-            provider="gcp",
             size=100000000,
             createdAt="2020-12-31T23:59:59.000Z",
         ),
@@ -66,7 +63,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="not ready",
             status="new",
-            provider="trainml",
             size=100000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -76,7 +72,6 @@ def mock_my_datasets():
             customer_uuid="cus-id-1",
             name="failed",
             status="failed",
-            provider="trainml",
             size=100000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -92,42 +87,24 @@ def mock_public_datasets():
             dataset_uuid="11",
             name="first one",
             status="ready",
-            provider="trainml",
         ),
         Dataset(
             trainml,
             dataset_uuid="12",
             name="second one",
             status="ready",
-            provider="trainml",
-        ),
-        Dataset(
-            trainml,
-            dataset_uuid="13",
-            name="first one",
-            status="ready",
-            provider="gcp",
-        ),
-        Dataset(
-            trainml,
-            dataset_uuid="14",
-            name="other one",
-            status="ready",
-            provider="gcp",
         ),
         Dataset(
             trainml,
             dataset_uuid="15",
             name="not ready",
             status="new",
-            provider="trainml",
         ),
         Dataset(
             trainml,
             dataset_uuid="16",
             name="failed",
             status="failed",
-            provider="trainml",
         ),
     ]
 
@@ -142,7 +119,6 @@ def mock_models():
             customer_uuid="cus-id-1",
             name="first one",
             status="ready",
-            provider="trainml",
             size=10000000,
             createdAt="2020-12-31T23:59:59.000Z",
         ),
@@ -152,37 +128,15 @@ def mock_models():
             customer_uuid="cus-id-1",
             name="second one",
             status="ready",
-            provider="trainml",
             size=10000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
-        Model(
-            trainml,
-            model_uuid="3",
-            customer_uuid="cus-id-1",
-            name="first one",
-            status="ready",
-            provider="gcp",
-            size=10000000,
-            createdAt="2021-01-01T00:00:01.000Z",
-        ),
-        Model(
-            trainml,
-            model_uuid="4",
-            customer_uuid="cus-id-1",
-            name="other one",
-            status="ready",
-            provider="gcp",
-            size=10000000,
-            createdAt="2020-12-31T23:59:59.000Z",
-        ),
         Model(
             trainml,
             model_uuid="5",
             customer_uuid="cus-id-1",
             name="not ready",
             status="new",
-            provider="trainml",
             size=10000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -192,7 +146,6 @@ def mock_models():
             customer_uuid="cus-id-1",
             name="failed",
             status="failed",
-            provider="trainml",
             size=10000000,
             createdAt="2021-01-01T00:00:01.000Z",
         ),
@@ -206,10 +159,8 @@ def mock_gpu_types():
         GpuType(
             trainml,
             **{
-                "available": 0,
-                "credits_per_hour": 3.9,
                 "name": "A100",
-                "provider": "gcp",
+                "price": {"min": 2.78, "max": 4.9},
                 "id": "a100-id",
                 "abbrv": "a100",
             },
@@ -217,10 +168,8 @@ def mock_gpu_types():
         GpuType(
             trainml,
             **{
-                "available": 100,
-                "credits_per_hour": 2.8,
+                "price": {"min": 1, "max": 3.94},
                 "name": "V100",
-                "provider": "gcp",
                 "id": "v100-id",
                 "abbrv": "v100",
             },
@@ -228,10 +177,8 @@ def mock_gpu_types():
         GpuType(
             trainml,
             **{
-                "available": 20,
-                "credits_per_hour": 0.35,
+                "price": {"min": 0.35, "max": 0.35},
                 "name": "RTX 2080 Ti",
-                "provider": "trainml",
                 "id": "2080ti-id",
                 "abbrv": "rtx2080ti",
             },
@@ -239,36 +186,12 @@ def mock_gpu_types():
         GpuType(
             trainml,
             **{
-                "available": 4,
-                "credits_per_hour": 0.1,
+                "price": {"min": 0.1, "max": 0.1},
                 "name": "GTX 1060",
-                "provider": "trainml",
                 "id": "1060-id",
                 "abbrv": "gtx1060",
             },
         ),
-        GpuType(
-            trainml,
-            **{
-                "available": 0,
-                "credits_per_hour": 0.28,
-                "name": "RTX 2070 Super",
-                "provider": "trainml",
-                "id": "2070s-id",
-                "abbrv": "rtx2070s",
-            },
-        ),
-        GpuType(
-            trainml,
-            **{
-                "available": 16,
-                "credits_per_hour": 0.7,
-                "name": "K80",
-                "provider": "gcp",
-                "id": "k80-id",
-                "abbrv": "k80",
-            },
-        ),
     ]
 
 
@@ -389,7 +312,6 @@ def mock_jobs():
                     }
                 ],
                 "worker_status": "new",
-                "provider": "trainml",
                 "resources": {
                     "gpu_count": 1,
                     "gpu_type_id": "1060-id",
@@ -473,7 +395,6 @@ def mock_jobs():
                     },
                 ],
                 "worker_status": "stopped",
-                "provider": "trainml",
                 "resources": {
                     "gpu_count": 1,
                     "gpu_type_id": "1060-id",
@@ -528,7 +449,6 @@ def mock_projects():
             **{
                 "id": "cus-id-1",
                 "name": "Personal",
-                "provider": "trainml",
                 "owner": True,
                 "owner_name": "Me",
                 "created_name": "Me",
@@ -543,7 +463,6 @@ def mock_projects():
             **{
                 "id": "project-id-2",
                 "name": "My Other Project",
-                "provider": "trainml",
                 "owner": True,
                 "owner_name": "Me",
                 "created_name": "Me",
@@ -558,7 +477,6 @@ def mock_projects():
             **{
                 "id": "project-id-3",
                 "name": "Someone Elses Project",
-                "provider": "trainml",
                 "owner": False,
                 "owner_name": "Someone Else",
                 "created_name": "Someone Else",
@@ -571,6 +489,39 @@ def mock_projects():
     ]
 
 
+@fixture(scope="session")
+def mock_providers():
+    trainml = Mock()
+    yield [
+        Provider(
+            trainml,
+            **{
+                "customer_uuid": "cust-id-1",
+                "project_uuid": "prov-id-1",
+                "type": "physical",
+                "credits": 10.0,
+                "payment_mode": "stripe",
+                "regions": [],
+            },
+        ),
+        Provider(
+            trainml,
+            **{
+                "customer_uuid": "cust-id-1",
+                "project_uuid": "prov-id-2",
+                "type": "gcp",
+                "credits": 0.0,
+                "payment_mode": "credits",
+                "credentials": {
+                    "project": "proj-1",
+                    "id": "gcp@serviceaccount.com",
+                },
+                "regions": [],
+            },
+        ),
+    ]
+
+
 @fixture(scope="function")
 def mock_trainml(
     mock_my_datasets,
@@ -580,6 +531,7 @@ def mock_trainml(
     mock_environments,
     mock_jobs,
     mock_projects,
+    mock_providers,
 ):
     trainml = create_autospec(TrainML)
     trainml.active_project = None
@@ -590,6 +542,7 @@ def mock_trainml(
     trainml.jobs = create_autospec(Jobs)
     trainml.connections = create_autospec(Connections)
     trainml.projects = create_autospec(Projects)
+    trainml.providers = create_autospec(Providers)
     trainml.datasets.list = AsyncMock(return_value=mock_my_datasets)
     trainml.datasets.list_public = AsyncMock(return_value=mock_public_datasets)
     trainml.models.list = AsyncMock(return_value=mock_models)
@@ -597,4 +550,5 @@ def mock_trainml(
     trainml.environments.list = AsyncMock(return_value=mock_environments)
     trainml.jobs.list = AsyncMock(return_value=mock_jobs)
     trainml.projects.list = AsyncMock(return_value=mock_projects)
+    trainml.providers.list = AsyncMock(return_value=mock_providers)
     yield trainml
